# ExifTool Version History

RSS feed: https://exiftool.org/rss.xml

Note: The most recent production release is Version 12.76. (Other versions are considered development releases, and are not uploaded to MetaCPAN.)

Apr. 23, 2024 - Version 12.84

- Added ability to read speed and accuracy_horizontal when geotagging from OpenTracks GPX files
- Decode a few more Apple tags and a new CanonVRD tag
- Enhanced Geolocation option with the ability to return any number of nearby cities
- Fixed long-standing bug in Windows version that didn't properly handle dates older than 50 years when writing FileModifyDate or FileCreateDate
- Fixed API TimeZone option to work in Windows
- Fixed problem where the SetTags helper function didn't properly copy tags which have print conversions
- Fixed problem where a new subregion couldn't be added through a user-defined Geolocation database entry
- Fixed problem where GeolocFeature option didn't work for some features if a user-generated custom database was used

Apr. 18, 2024 - Version 12.83

- Added SetTags helper function for use in advanced formatting expressions
- Added a couple of new tags from the DNG 1.7.1 specification
- Added a new Nikon Z lens
- Added a couple of new QuickTime tags
- Added a few more XMP-GCamera tags
- Added build_geolocation utility to the full distribution
- Decode a new CanonVRD tag and rename another one
- Updates to Sony maker note decoding for newer models (thanks Jos Roost)
- Minor change in -p option to avoid adding the trailing newline if the -b option is also used
- Minor changes to GM PDR decoding for Gear and angle measurements
- Removed Geolocation alternate language support from the standard distribution, and added PPLX feature codes
- Set family 1 group name for NextBase 'nbmt' information to "Nextbase"
- Fixed incorrect ID of a DNG tag
- API Changes:
  - Added IgnoreGroups option

Apr. 5, 2024 - Version 12.82 - "GM PDR"

- Added support for reading GM PDR data from MP4 videos written by cars such as Corvettes and Cameros
- Added support for reading timed GPS from Wolfbox dashcam videos
- Added "Unknown trailer" to QuickTime warnings originating from an unknown trailer
- Added a new Nikon LensID
- Extract PreviewImage from Chigee AIO-5 dashcam videos
- Changed name and print conversion of a recently added FujiFilm tag
- Only issue "Tag not defined" warnings for the first sub-document when using the -p option
- Fixed a Nikon Z lens name (github #250)
- Fixed Windows version so -sort works properly with -listgeo
- API Changes:
  - Added PrintCSV option for optimized extraction of GM PDR data in CSV format

Mar. 27, 2024 - Version 12.81

- Added ability to read EXIF and XMP from EXR images
- Added ability to delete unknown trailer when writing MOV/MP4 videos
- Added ability to write a couple of Stable Diffusion PNG tags
- Added ability to write one of the Microsoft Xtra Description tags (github #248)
- Added support for using alternate city names in reverse Geolocation
- Added support for reading timed GPS from DOD LS600W TS videos
- Added support for new version of Canon DR4 files
- Added a number of new iTunesInfo tags
- Added a new Olympus LensType
- Decode a number of new Nikon tags (thanks Warren Hatch)
- Allow regular expressions to be used when writing Geolocate tag
- Enhanced writing of Geolocate tag to also write Keys:LocationName
- Cache the results of the last reverse geolocation search to speed batch processing when multiple files have the same search parameters
- Patched problem that could cause runtime errors with some invaid tag names
- Fixed a couple of newly added FujiFilm tags
- Fixed decoding of FujiFilm AFAreaZoneSize
- API Changes:
  - Added GeolocAltNames option

Mar. 19, 2024 - Version 12.80

- Added GeolocationFeatureCode tag
- Added XMP-acdsee-rs tags and a new XMP-xmpDM tag
- Added ACDSeeRegion2MWGRegion conversion to config_files/acdsee.config
- Added GPSAltitudeRef to XMP-iptcExt LocationDetails structure
- Added a couple of new FujiFilm tags and a new CropMode value
- Added conversion for XMP-aux:ApproximateFocusDistance "infinity"
- Improved Geolocation regular expressions to allow negative matches
- Improved accuracy of Geolocation distance/bearing calculations
- Changed structure of Geolocation database (now version 1.02)
- Minor change to key format for user-defined Geolocation name translations
- Ignore API Geolocation option when copying tags if none of the Geolocation tags are being copied
- Fixed case/spacing of "C2PA" in some CBOR tag descriptions
- Fixed bug extracting binary data from EXR files
- API Changes:
  - Added GeolocFeature option

Mar. 15, 2024 - Version 12.79

- Improvements to new Geolocation feature:
  - Added reverse Geolocation ability (obtain GPS coordinates from city name), with support for regular expressions
  - Added ability to geolocate while geotagging
  - Added -listgeo option to list the Geolocation database
  - Added the ability to include user-defined cities in the Geolocation database
  - Added the ability to write XMP-iptcExt LocationShown tags using Geolocate feature
  - Added the ability to specify which tags to read from file for the API Geolocation option
  - Added language translations for Geolocation names
  - Increased resolution of Geolocation GPS positions and stored populations
- API Changes:
  - Save necessary data members to allow GetInfo to be accessed by user-defined tags

Mar. 5, 2024 - Version 12.78 - "Geolocation"

- Added new Geolocation feature and write-only Geolocate tag
- Added new config file entry (@Image::ExifTool::UserDefined::Arguments) to allow default command-line arguments to be specified
- Added print conversion for TIFF-EPStandardID
- Added ability to delete Nextbase information from MP4 videos
- Decode timed GPS from MP4 videos written by Nextbase software
- Decode a number of new tags from Nextbase MP4 videos
- Decode a few new tags from Garmin MP4 videos
- Extract PreviewJXL images from DNG 1.7 files
- Generate Validate, ImageDataHash and UserParam tags earlier to allow them to be used in UserDefined Composite tags
- Enhanced the -c option so a minus sign in the format specification prints a signed coordinate without a leading "+" for positive numbers
- Changed formatting of some Accelerometer tags for consistency
- Changed behaviour of -ee3 option to do a brute-force scan for freeGPS in the media data even when referenced by 'gps ' atom
- Other internal changes to decoding of timed GPS from videos
- Fixed problem were ExifTool would give up on extracting some types of timed GPS from videos after 100 void fixes
- Fixed bug that could cause runtime error when reading Ogg files
- Fixed issue where some tags from alternate files using the -fileNUM option weren't generated as requested
- API Changes:
  - Added Geolocation, GeolocMaxDist and GeolocMinPop API options

Feb. 16, 2024 - Version 12.77

- Added new Olympus CameraType and LensType value (thanks herb)
- Added a new Canon Irix LensType
- Added the ability to delete MacOS XAttrMDItemWhereFroms
- Decode a few new Canon DPP tags (thanks John Moyer)
- Decode timed GPS from Adzome GS65H MOV videos
- Improved handling of XML-unfriendly characters in JSON field names (fixes issue where -X option could produce invalid XML when reading JSON with the -struct option)
- Fixed decoding of ShutterCount for Canon G5X-ii CR3 files

Jan. 31, 2024 - Version 12.76 (production release)

- Properly implement patch of 12.45 to avoid duplicating raw data when writing Sony ARW images where the raw data is double-referenced as both strips and tiles
- Improved handling of bad offsets in HtmlDump output

Jan. 30, 2024 - Version 12.75 (production release)

- CORRUPTION WARNING: Fixed bug introduced in 12.45 which could result in corrupted Sony ARW images from some newer models when rewriting lossless compressed ARW images which were previously edited by 12.44 or earlier (the corruption is repairable, but requires a special version of ExifTool)
- Added ability to read C2PA JUMBF metadata from PDF and SVG files
- Added ability to extract JUMBF metadata as a block
- Added read support for C2PA (JUMBF-format) files
- Removed "date before 1970" warning entirely since 64-bit systems should be able to handle dates in this range
- Improved Canon FocusMode decoding
- Fixed bug introducd in 12.74 which could cause "Undefined subroutine" runtime error when reading MIE files

Jan. 23, 2024 - Version 12.74

- Added a couple of new Nikon lenses (thanks Chris)
- Added write support for a few new QuickTime Keys tags
- Decode ShutterCount for Canon EOS R5 (thanks John Moyer)
- Improved error messages in the case of file read errors
- Enhanced tag name strings (eg. -if and -p option arguments) to allow values of multiple matching tags to be concatenated when a group name of "All" is specified
- Enhanced -p option to add -p- feature which avoids adding trailing newline
- Changed warning from "Shift results in negative time" to "Shift results in date before 1970"
- Patched calculation of GPSDateTime for the timed metadata in Track3 of Garmin videos so the API QuickTimeUTC option is no longer required
- Fixed conversion error when writing QuickTime:GoogleTrackDuration
- Fixed misidentification of non-TIFF-format files containing DNGVersion tag
- Fixed bug where Avoid-ed XMP structures could be created when writing another same-named structure
- Internal Changes:
  - Changed form of all new() calls to accommodate backward incompatibilities in recent versions of Perl
  - Changed order of InsertTagValues() arguments
  - DateFmt() now returns value of formatted date/time string

Jan. 10, 2024 - Version 12.73

- Added write support for Leica XMP-xmpDSA tags
- Added read support for timed GPS from Yada RoadCam Pro 4K dashcam videos
- Added read support for PNG cpIp chunk
- Added range checks on lat/long values when writing QuickTime:GPSCoordinates
- Decode a number of new values for Ricoh GR III tags
- Decode a new Leica tag
- Improved handling of Brotli compression errors
- Enhanced API NoWarning option to also apply to app "Warning:" outputs
- Identify PNG Plus files
- Changed name of Pentax ISOAutoParameters to ISOAutoMinSpeed and improved decoding
- Fixed writing of date/time tags in XMP-xmpMM:Pantry structure
- API Changes:
  - Added LimitLongValues option to provide control over tags which previously had a hard-coded length limit

Dec. 29, 2023 - Version 12.72

- Added read support for AAC audio files
- Added a new QuickTime Keys Android tag
- Added a number of new values for some Ricoh GR III tags
- Decode timed metadata from Intsa360 Ace Pro MP4 videos
- Decode GPSDateTime milliseconds in timed Insta360 metadata
- Decode timed metadata from INNOV K5 TS videos
- Decode a number of new GoPro timed-metadata tags
- Decode a few new Xiaomi EXIF tags
- Fixed writing of JPG/ARW images from some newer Sony models to preserve HiddenData

Dec. 21, 2023 - Version 12.71

- Added a warning if there was an error reading an alternate file with the -fileNUM option
- Added the ability to write QuickTime Keys:Encoder
- Added a few new Canon LensType values (thanks Norbert Wasser)
- Added a new, obscure EXIF tag (thanks Neal Krawetz)
- Decode real-time metadata from Ricoh Theta videos
- Decode SpecularWhiteLevel for more Canon models (github #232)
- Decode Canon DualPixelRaw tag (thanks John Moyer)
- Decode a few new Nikon tags (thanks Warren Hatch)
- Decode more FujiFilm M-RAW tags (thanks Greybeard)
- Improved generation of tag names for some JSON tag ID's containing colons
- Fixed "Undefined subroutine" error when writing makernotes as a block
- Fixed missing ID in family 7 group name for ID3 tags which are not valid for the specified ID3 version
- Fixed bug where some tags from alternate files (with the -fileNUM option) could show up as "not defined" when used in expressions even though they did exist
- API Changes:
  - Added NoMandatory option

Nov. 19, 2023 - Version 12.70 (production release) - "20th Anniversary"

- This marks the 20th anniversary of the initial ExifTool release!
- Added ability to read/delete C2PA CAI JUMBF metadata from TIFF-based images (eg. DNG), QuickTime-based files (eg. MP4) and WebP images, and read JUMBF from other RIFF-based files (eg. WAV, AVI), GIF images and ID3v2 metadata
- Added read/write support for JPH images
- Added ability to read Leica Q3 maker notes
- Added ability to recognize and write FujiFilm M-RAW RAF images (multiple raw images in a single file) and the ability to read preview-less RAF images
- Added support for reading a number of obscure Microsoft EXIF tags
- Added a few new Sony lenses and support for the ILCE-9M3 (thanks Jos Roost)
- Added a couple of new Panasonic Leica lenses
- Added a couple of new Canon RF lenses (thanks Norbert Wasser)
- Added a number of new CPUType values for ELF executables
- Added some new Olympus CameraType values
- Decode a few more ID3v2.2 tags (github #142)
- Decode a few new Canon G5X Mark II tags (thanks Martin B.)
- Decode WB_RGGBLevels for a few more Nikon cameras
- Extract information from FujiFilm M-RAW header
- Improved decoding of a few Nikon Z tags (thanks Warren Hatch)
- Marked misspelt XMP-drone-dji:GPSLongtitude tag to Avoid when writing
- Changed RIFF MaxDataRate conversion to use SI prefixes by default
- Fixed decoding of unknown ColorBalance information for some Nikon models
- Fixed an incorrect Nikon Z LensID
- API Changes:
  - Added ByteUnit option

History of older versions (back to Nov. 19, 2003 - Version 1.00) -->

<-- Back to ExifTool home page